@@ -1,11 +1,12 @@
 #!/usr/bin/env lua
 -- removes OpenWrt/LEDE default wifi-iface settings, if present
 
-require('uci')
+local uci = require('uci')
 
 -- parse arguments
+local test
 local arg={...}
-for key, value in pairs(arg) do
+for _, value in pairs(arg) do
     -- test argument
     if value == '--test=1' then test = true; end
 end
@@ -16,7 +17,7 @@ local standard_path = standard_prefix .. 'config/'
 local standard = uci.cursor(standard_path)
 local changed = false
 
-function is_default_wifi(section)
+local function is_default_wifi(section)
     if section.encryption == 'none' and
        section.mode == 'ap'         and
        section.network == 'lan'     and
