@@ -1,10 +1,12 @@
 #!/usr/bin/env lua
 -- restores unmanaged configurations
 
-require('uci')
-require('openwisp.utils')
+local uci = require('uci')
+local lfs = require('lfs')
+local utils = require('openwisp.utils')
 
 -- parse arguments
+local test = false
 local arg={...}
 for key, value in pairs(arg) do
     -- test argument
@@ -25,7 +27,7 @@ for file in lfs.dir(unmanaged_path) do
     if file ~= '.' and file ~= '..' then
         for key, section in pairs(unmanaged:get_all(file)) do
             standard:delete(file, key)
-            write_uci_section(standard, file, section)
+            utils.write_uci_section(standard, file, section, true)
         end
         standard:commit(file)
     end
